@@ -11,13 +11,13 @@ setMethod("burst",
           })
 
 setMethod("burst", 
-          signature=c(x = "Move", f = "numeric"), 
+          signature=c(x = "ANY", f = "numeric"), 
           definition = function(x, f, ...) {
             burst(x = x, f = as.factor(f))
           })
 
 setMethod("burst", 
-          signature=c(x = "Move", f = "character"), 
+          signature=c(x = "ANY", f = "character"), 
           definition = function(x, f, ...) {
             if (length(f) == 1) {
                 burst(x = x, f = do.call("$", list(x, f))[-n.locs(x)])
@@ -26,6 +26,15 @@ setMethod("burst",
             }
           })
 
+setMethod("burst", 
+          signature=c(x = ".MoveTrackSingleBurst", f = "factor"), 
+          definition = function(x, f, ...) {
+         burstId(x)<-f
+            return(x)
+          })
+
+
+
 setMethod('burst',
 	  signature=c(x='.MoveTrackSingleBurst', 'missing'),
 	  definition=function(x,f,...){
@@ -34,7 +43,6 @@ setMethod('burst',
 
 
 setAs("MoveBurst", "Move", function(from) {
-# last id can be different since that one is not telling anything about a segment in this obj
       if (length(unique(from@burstId)) != 1) 
         stop("Does not work with one burst id only")
       new("Move", 
@@ -42,7 +50,6 @@ setAs("MoveBurst", "Move", function(from) {
           as(from,".MoveTrackSingle"))
     }) 
 setAs("MoveStack", "Move", function(from) {
-# last id can be different since that one is not telling anything about a segment in this obj
       if (length(unique(from@trackId)) != 1) 
         stop("Does only work with one id")
       new("Move", 
